pub struct PropertyDeclarationContext<'a> {
property_id: Option<PropertyIdRef<'a>>,
random_count: Cell<i32>,
}Expand description
Context for the property declaration that is currently being parsed.
Fields
property_id: Option<PropertyIdRef<'a>>Reference to the current property’s name/ID.
random_count: Cell<i32>Current count of random() functions that have been parsed so far
in the current property declaration. Used when a random() function
has a property-index-scoped key.
Implementations
Sourceimpl<'a> PropertyDeclarationContext<'a>
impl<'a> PropertyDeclarationContext<'a>
fn set(&mut self, property_id: PropertyIdRef<'a>)
fn clear(&mut self)
Sourcepub fn property_id(&self) -> Option<PropertyIdRef<'a>>
pub fn property_id(&self) -> Option<PropertyIdRef<'a>>
The declaration being parsed, if any.
Sourcepub fn current_random_index(&self) -> i32
pub fn current_random_index(&self) -> i32
The index of the current random() function in this declaration.
Sourcepub fn increment_random_count(&self) -> i32
pub fn increment_random_count(&self) -> i32
Claims the next index for a random() function in this declaration. The index is 1-based and follows the order the functions appear in the parsed value.